@@ -2,6 +2,7 @@
 import logging
 import logging.config
 import sys
+import random
 
 if sys.platform in ['win32', 'cygwin']:
     import ntpath as ospath
@@ -105,18 +106,27 @@ def _assign_address(instance_id, address):
 
 def _get_unassociated_address():
     """ Return the first unassociated EIP we can find
+    Shuffles list before iterating to alleviate collisions
 
     :returns: boto.ec2.address or None
     """
     eip = None
-
-    for address in connection.get_all_addresses():
+    
+    all_addresses = connection.get_all_addresses()
+    random.shuffle(all_addresses)
+    for address in all_addresses:
         # Check if the address is associated
         if address.instance_id:
             logger.debug('{0} is already associated with {1}'.format(
                 address.public_ip, address.instance_id))
             continue
 
+        # Check if the address is attached to an ENI
+        if address.network_interface_id:
+            logger.debug('{0} is already attached to {1}'.format(
+                address.public_ip, address.network_interface_id))
+            continue
+
         # Check if the address is in the valid IP's list
         if _is_valid(address.public_ip):
             logger.debug('{0} is unassociated and OK for us to take'.format(
@@ -146,18 +156,19 @@ def _has_associated_address(instance_id):
         return True
     return False
 
-
-def _is_valid(address):
-    """ Check if the configuration allows us to assign this address
+def _is_ip_in_range(address, ips):
+    """ Check if the IP is in a given range.
 
     :type address: str
     :param address: IP address to check
+    :type ips: str
+    :param ips: IP range
     :returns: bool -- True if association is OK
     """
-    if not args.valid_ips:
+    if not ips:
         return True
 
-    for conf_ip in args.valid_ips.split(','):
+    for conf_ip in ips.split(','):
         try:
             for ip in IPNetwork(conf_ip):
                 if str(ip) == str(address):
@@ -172,3 +183,19 @@ def _is_valid(address):
             pass
 
     return False
+
+
+def _is_valid(address):
+    """ Check if the configuration allows us to assign this address
+
+    :type address: str
+    :param address: IP address to check
+    :returns: bool -- True if association is OK
+    """
+    if _is_ip_in_range(address, args.valid_ips):
+        if args.invalid_ips and _is_ip_in_range(address, args.invalid_ips):
+            return False
+        else:
+            return True
+
+    return False
