@@ -1,7 +1,10 @@
 """ Command line parser """
 import argparse
 import sys
-from ConfigParser import SafeConfigParser
+try:
+    from ConfigParser import SafeConfigParser
+except ImportError:
+    from configparser import SafeConfigParser
 from argparse import RawTextHelpFormatter
 
 if sys.platform in ['win32', 'cygwin']:
@@ -44,6 +47,15 @@ PARSER.add_argument(
         '- 58.0.0.0/8\n'
         '- 123.213.0.0/16,58.0.0.0/8,195.234.023.0\n'
         '- 195.234.234.23,195.234.234.24\n'))
+PARSER.add_argument(
+    '--invalid-ips',
+    help=(
+        'A comma separated list of Elastic IP ranges that should not '
+        'be used for assigning an ip. \n  You can use CIDR '
+        'expressions to select ranges.\nValid examples:\n'
+        '- 58.0.0.0/8\n'
+        '- 123.213.0.0/16,58.0.0.0/8,195.234.023.0\n'
+        '- 195.234.234.23,195.234.234.24\n'))
 ARGS = PARSER.parse_args()
 
 if ARGS.version:
